@@ -324,7 +324,7 @@ static void Version(int argc UNUSED, char *argv[]UNUSED)
 {
 	PrintVersion();
 
-	printf("%s\n", _("Copyright (C) 2003 - 2011 Michal Cihar <michal@cihar.com> and other authors."));
+	printf("%s\n", _("Copyright (C) 2003 - 2012 Michal Cihar <michal@cihar.com> and other authors."));
 
 	printf("\n");
 
@@ -640,7 +640,7 @@ static GSM_Parameters Parameters[] = {
 #if defined(WIN32) || defined(HAVE_PTHREAD)
 	{"searchphone",		0, 1, SearchPhone,		{H_Other,0},			"[-debug]"},
 #endif
-	{"install",			0, 0, Install,			{H_Other,0},			""},
+	{"install",			0, 1, Install,			{H_Other,0},			"[-minimal]"},
 #ifdef GSM_ENABLE_BACKUP
 	{"savefile",			4, 5, SaveFile,			{H_Backup,H_Calendar,0},	"CALENDAR target.vcs file location"},
 	{"savefile",			4, 5, SaveFile,			{H_Backup,H_ToDo,0},		"TODO target.vcs file location"},
