@@ -274,6 +274,7 @@ GSM_PhoneModel allmodels[] = {
 	{"1681c","RH-118","Nokia 1681c",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,F_PBKNOPOSTAL,0}},/* guess */
 	{"2323c","RH-543","Nokia 2323c",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
 	{"2330c","RH-512","Nokia 2330c",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
+	{"2330c","RM-512","Nokia 2330c",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,F_PBKNOPOSTAL,F_6230iCALLER,0}},/* guess */
 	{"2600", "RM-340","Nokia 2600",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,F_PBKNOPOSTAL,F_6230iCALLER,0}},/* guess */
 	{"2610", "RH-86", "Nokia 2610",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
 	{"2610", "RH-87" ,"Nokia 2610",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* guess */
@@ -342,6 +343,7 @@ GSM_PhoneModel allmodels[] = {
 	{"6200" ,"NPL-3" ,"Nokia 6200", {F_PBKTONEGAL,0}},
 	{"6220" ,"RH-20" ,"Nokia 6220", {F_PBKTONEGAL,F_TODO66,F_RADIO,F_PBKSMSLIST,F_PBKUSER,F_WAPMMSPROXY,F_NOTES,F_CHAT,F_SYNCML,0}},
 	{"6220c","RM-328","Nokia 6220c",{F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,F_6230iCALLER,0}},/* fixme */
+	{"6225" ,"RH-27" ,"Nokia 6225", {F_PBKTONEGAL,F_TODO66,F_RADIO,F_PBKSMSLIST,F_PBKUSER,F_WAPMMSPROXY,F_NOTES,F_CHAT,F_SYNCML,F_FILES2,0}},
 	{"6230" ,"RH-12" ,"Nokia 6230", {F_PBKTONEGAL,F_TODO66,F_RADIO,F_PBKSMSLIST,F_PBKUSER,F_WAPMMSPROXY,F_NOTES,F_CHAT,F_SYNCML,F_FILES2,0}},
 	{"6230" ,"RH-28" ,"Nokia 6230", {F_PBKTONEGAL,F_TODO66,F_RADIO,F_PBKSMSLIST,F_PBKUSER,F_WAPMMSPROXY,F_NOTES,F_CHAT,F_SYNCML,F_FILES2,0}},
 	{"6230i","RM-72" ,"Nokia 6230i",{F_PBKTONEGAL,F_TODO66,F_RADIO,F_PBKSMSLIST,F_PBKUSER,F_WAPMMSPROXY,F_NOTES,F_CHAT,F_SYNCML,F_FILES2,F_6230iWAP,F_6230iCALLER,0}},
@@ -423,6 +425,8 @@ GSM_PhoneModel allmodels[] = {
 	{"9300", "Nokia 9300", "Nokia 9300", {0}},
 	{"N70", "Nokia E70", "Nokia E70", {0}},
 	{"E61", "Nokia E61", "Nokia E61", {0}},
+	{"N950", "Nokia N950", "Nokia N950", {0}},
+	{"N9", "Nokia N9", "Nokia N9", {0}},
 
 	/* Siemens */
 	{"M20"  ,	  "M20",	  "",				   {F_M20SMS,F_SLOWWRITE,0}},
@@ -465,13 +469,8 @@ GSM_PhoneModel allmodels[] = {
 	{"J700",	  "SGH-J700" ,	  "",				   {F_NO_ATOBEX, 0}},
 	{"J700",	  "SAMSUNG SGH-J700" , "",			   {F_NO_ATOBEX, F_DISABLE_CMGL, 0}},
 	{"D980",	  "SAMSUNG SGH-D980" , "",			   {F_NO_ATOBEX, 0}},
-	{"B2100",         "SAMSUNG B2100", "", {F_DISABLE_CMGL,
-						F_SMS_SM, F_SMS_ME,
-						F_SMS_UTF8_ENCODED,
-						F_READ_SMSTEXTMODE,
-						F_FORCE_UTF8,
-						F_NO_UTF8, F_SAMSUNG_UTF8,
-						F_TSSPCSW, F_OBEX, F_IRMC_LEVEL_2, 0}},
+	{"B2100",         "SAMSUNG B2100", "",				   {F_DISABLE_CMGL, F_SMS_SM, F_SMS_ME, F_SMS_UTF8_ENCODED, F_READ_SMSTEXTMODE, F_FORCE_UTF8, F_NO_UTF8, F_SAMSUNG_UTF8, F_TSSPCSW, F_OBEX, F_IRMC_LEVEL_2, 0}},
+	{"GT-E2370",      "SAMSUNG GT-E2370", "",			   {F_DISABLE_CMGL, F_SMS_SM, F_SMS_ME, F_SMS_UTF8_ENCODED, F_READ_SMSTEXTMODE, F_FORCE_UTF8, F_NO_UTF8, F_SAMSUNG_UTF8, F_TSSPCSW, F_OBEX, F_IRMC_LEVEL_2, 0}},
 
 	/* Philips */
 	{"Xenium 9@9d",	  "Xenium 9@9d", "",				   {F_OBEX, 0}},
