@@ -604,6 +604,10 @@ GSM_Error ATGEN_ReplyGetSMSMessage(GSM_Protocol_Message *msg, GSM_StateMachine *
 
 			/* Parse reply */
 			error = ATGEN_ParseReply(s, buffer, "+CMGR: @i, @0", &state);
+			if (error == ERR_UNKNOWNRESPONSE) {
+				/* Some phones like ES75 lack state information, which we ignore anywa */
+				error = ATGEN_ParseReply(s, buffer, "+CMGR: @i", &state);
+			}
 			if (error != ERR_NONE) {
 				return error;
 			}
@@ -990,7 +994,7 @@ GSM_Error ATGEN_GetSMS(GSM_StateMachine *s, GSM_MultiSMSMessage *sms)
 	}
 	s->Phone.Data.GetSMSMessage = sms;
 	smprintf(s, "Getting SMS\n");
-	ATGEN_WaitFor(s, req, length, 0x00, 20, ID_GetSMSMessage);
+	ATGEN_WaitFor(s, req, length, 0x00, 50, ID_GetSMSMessage);
 
 	if (error == ERR_NONE || error == ERR_CORRUPTED) {
 		getfolder = sms->SMS[0].Folder;
