@@ -29,6 +29,18 @@
 #include "../core.h"
 #include "../../helper/string.h"
 
+/**
+ * Returns name of the SQL dialect to use.
+ */
+const char *SMSDSQL_SQLName(GSM_SMSDConfig * Config)
+{
+	if (Config->sql != NULL) {
+		return Config->sql;
+	} else {
+		return Config->driver;
+	}
+}
+
 /* FIXME: I know this is broken, need to figure out better way */
 const char now_plus_odbc[] = "{fn CURRENT_TIMESTAMP()} + INTERVAL %d SECOND";
 const char now_plus_mysql[] = "(NOW() + INTERVAL %d SECOND) + 0";
@@ -38,19 +50,13 @@ const char now_plus_freetds[] = "DATEADD('second', %d, CURRENT_TIMESTAMP)";
 const char now_plus_access[] = "now()+#00:00:%d#";
 const char now_plus_fallback[] = "NOW() + INTERVAL %d SECOND";
 
-/* configurable SQL queries */
-char * SMSDSQL_queries[SQL_QUERY_LAST_NO];
 
 static const char *SMSDSQL_NowPlus(GSM_SMSDConfig * Config, int seconds)
 {
 	const char *driver_name;
 	static char result[100];
 
-	if (Config->sql != NULL) {
-		driver_name = Config->sql;
-	} else {
-		driver_name = Config->driver;
-	}
+	driver_name = SMSDSQL_SQLName(Config);
 
 	if (strcasecmp(driver_name, "mysql") == 0 || strcasecmp(driver_name, "native_mysql") == 0) {
 		sprintf(result, now_plus_mysql, seconds);
@@ -81,11 +87,7 @@ static const char *SMSDSQL_EscapeChar(GSM_SMSDConfig * Config)
 {
 	const char *driver_name;
 
-	if (Config->sql != NULL) {
-		driver_name = Config->sql;
-	} else {
-		driver_name = Config->driver;
-	}
+	driver_name = SMSDSQL_SQLName(Config);
 
 	if (strcasecmp(driver_name, "mysql") == 0 || strcasecmp(driver_name, "native_mysql") == 0) {
 		return escape_char_mysql;
@@ -110,11 +112,7 @@ static const char *SMSDSQL_TopClause(GSM_SMSDConfig * Config, const char *count)
 	const char *driver_name;
 	static char result[100];
 
-	if (Config->sql != NULL) {
-		driver_name = Config->sql;
-	} else {
-		driver_name = Config->driver;
-	}
+	driver_name = SMSDSQL_SQLName(Config);
 
 	if (strcasecmp(driver_name, "access") == 0) {
 		strcpy(result, top_clause_access);
@@ -134,11 +132,7 @@ static const char *SMSDSQL_LimitClause(GSM_SMSDConfig * Config, const char *coun
 	const char *driver_name;
 	static char result[100];
 
-	if (Config->sql != NULL) {
-		driver_name = Config->sql;
-	} else {
-		driver_name = Config->driver;
-	}
+	driver_name = SMSDSQL_SQLName(Config);
 
 	if (strcasecmp(driver_name, "access") == 0) {
 		return limit_clause_access;
@@ -169,11 +163,7 @@ static const char *SMSDSQL_CurrentTime(GSM_SMSDConfig * Config)
 {
 	const char *driver_name;
 
-	if (Config->sql != NULL) {
-		driver_name = Config->sql;
-	} else {
-		driver_name = Config->driver;
-	}
+	driver_name = SMSDSQL_SQLName(Config);
 
 	if (strcasecmp(driver_name, "mysql") == 0 || strcasecmp(driver_name, "native_mysql") == 0) {
 		return currtime_mysql;
@@ -193,11 +183,7 @@ static const char *SMSDSQL_Now(GSM_SMSDConfig * Config)
 {
 	const char *driver_name;
 
-	if (Config->sql != NULL) {
-		driver_name = Config->sql;
-	} else {
-		driver_name = Config->driver;
-	}
+	driver_name = SMSDSQL_SQLName(Config);
 
 	if (strcasecmp(driver_name, "mysql") == 0 || strcasecmp(driver_name, "native_mysql") == 0) {
 		return now_mysql;
@@ -252,11 +238,7 @@ void SMSDSQL_Time2String(GSM_SMSDConfig * Config, time_t timestamp, char *static
 	struct tm *timestruct;
 	const char *driver_name;
 
-	if (Config->sql != NULL) {
-		driver_name = Config->sql;
-	} else {
-		driver_name = Config->driver;
-	}
+	driver_name = SMSDSQL_SQLName(Config);
 
 	if (timestamp == -2) {
 		strcpy(static_buff, "0000-00-00 00:00:00");
@@ -473,8 +455,8 @@ static GSM_Error SMSDSQL_Free(GSM_SMSDConfig * Config)
 	Config->db->Free(Config);
 	/* free configuration */
 	for(i = 0; i < SQL_QUERY_LAST_NO; i++){
-		free(SMSDSQL_queries[i]);
-		SMSDSQL_queries[i] = NULL;
+		free(Config->SMSDSQL_queries[i]);
+		Config->SMSDSQL_queries[i] = NULL;
 	}
 	return ERR_NONE;
 }
@@ -544,7 +526,7 @@ static GSM_Error SMSDSQL_InitAfterConnect(GSM_SMSDConfig * Config)
 	struct GSM_SMSDdbobj *db = Config->db;
 	SQL_Var vars[3] = {{SQL_TYPE_STRING, {NULL}}, {SQL_TYPE_STRING, {NULL}}, {SQL_TYPE_NONE, {NULL}}};
 
-	if (SMSDSQL_NamedQuery(Config, SMSDSQL_queries[SQL_QUERY_DELETE_PHONE], NULL, NULL, &res) != SQL_OK) {
+	if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_DELETE_PHONE], NULL, NULL, &res) != SQL_OK) {
 		SMSD_Log(DEBUG_INFO, Config, "Error deleting from database (%s)", __FUNCTION__);
 		return ERR_UNKNOWN;
 	}
@@ -554,7 +536,7 @@ static GSM_Error SMSDSQL_InitAfterConnect(GSM_SMSDConfig * Config)
 	vars[0].v.s = Config->enable_send ? "yes" : "no";
 	vars[1].v.s = Config->enable_receive ? "yes" : "no";
 
-	if (SMSDSQL_NamedQuery(Config, SMSDSQL_queries[SQL_QUERY_INSERT_PHONE], NULL, vars, &res) != SQL_OK) {
+	if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_INSERT_PHONE], NULL, vars, &res) != SQL_OK) {
 		SMSD_Log(DEBUG_INFO, Config, "Error inserting into database (%s)", __FUNCTION__);
 		return ERR_UNKNOWN;
 	}
@@ -591,7 +573,7 @@ static GSM_Error SMSDSQL_SaveInboxSMS(GSM_MultiSMSMessage * sms, GSM_SMSDConfig
 			EncodeUTF8(smstext, sms->SMS[i].Text);
 			SMSD_Log(DEBUG_INFO, Config, "Delivery report: %s to %s", smstext, destinationnumber);
 
-			if (SMSDSQL_NamedQuery(Config, SMSDSQL_queries[SQL_QUERY_SAVE_INBOX_SMS_SELECT], &sms->SMS[i], NULL, &res) != SQL_OK) {
+			if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_SAVE_INBOX_SMS_SELECT], &sms->SMS[i], NULL, &res) != SQL_OK) {
 				SMSD_Log(DEBUG_INFO, Config, "Error reading from database (%s)", __FUNCTION__);
 				return ERR_UNKNOWN;
 			}
@@ -629,9 +611,9 @@ static GSM_Error SMSDSQL_SaveInboxSMS(GSM_MultiSMSMessage * sms, GSM_SMSDConfig
 
 			if (found) {
 				if (!strcmp(smstext, "Delivered")) {
-					q = SMSDSQL_queries[SQL_QUERY_SAVE_INBOX_SMS_UPDATE_DELIVERED];
+					q = Config->SMSDSQL_queries[SQL_QUERY_SAVE_INBOX_SMS_UPDATE_DELIVERED];
 				} else {
-					q = SMSDSQL_queries[SQL_QUERY_SAVE_INBOX_SMS_UPDATE];
+					q = Config->SMSDSQL_queries[SQL_QUERY_SAVE_INBOX_SMS_UPDATE];
 				}
 
 				if (!strcmp(smstext, "Delivered")) {
@@ -665,7 +647,7 @@ static GSM_Error SMSDSQL_SaveInboxSMS(GSM_MultiSMSMessage * sms, GSM_SMSDConfig
 		if (sms->SMS[i].PDU != SMS_Deliver)
 			continue;
 
-		if (SMSDSQL_NamedQuery(Config, SMSDSQL_queries[SQL_QUERY_SAVE_INBOX_SMS_INSERT], &sms->SMS[i], NULL, &res) != SQL_OK) {
+		if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_SAVE_INBOX_SMS_INSERT], &sms->SMS[i], NULL, &res) != SQL_OK) {
 			SMSD_Log(DEBUG_INFO, Config, "Error writing to database (%s)", __FUNCTION__);
 			return ERR_UNKNOWN;
 		}
@@ -691,7 +673,7 @@ static GSM_Error SMSDSQL_SaveInboxSMS(GSM_MultiSMSMessage * sms, GSM_SMSDConfig
 			locations_pos += sprintf((*Locations) + locations_pos, "%lu ", (long)new_id);
 		}
 
-		if (SMSDSQL_NamedQuery(Config, SMSDSQL_queries[SQL_QUERY_UPDATE_RECEIVED], &sms->SMS[i], NULL, &res2) != SQL_OK) {
+		if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_UPDATE_RECEIVED], &sms->SMS[i], NULL, &res2) != SQL_OK) {
 			SMSD_Log(DEBUG_INFO, Config, "Error updating number of received messages (%s)", __FUNCTION__);
 			return ERR_UNKNOWN;
 		}
@@ -710,7 +692,7 @@ static GSM_Error SMSDSQL_RefreshSendStatus(GSM_SMSDConfig * Config, char *ID)
 		{SQL_TYPE_STRING, {ID}},
 		{SQL_TYPE_NONE, {NULL}}};
 
-	if (SMSDSQL_NamedQuery(Config, SMSDSQL_queries[SQL_QUERY_REFRESH_SEND_STATUS], NULL, vars, &res) != SQL_OK) {
+	if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_REFRESH_SEND_STATUS], NULL, vars, &res) != SQL_OK) {
 		SMSD_Log(DEBUG_INFO, Config, "Error writing to database (%s)", __FUNCTION__);
 		return ERR_UNKNOWN;
 	}
@@ -732,56 +714,48 @@ static GSM_Error SMSDSQL_FindOutboxSMS(GSM_MultiSMSMessage * sms, GSM_SMSDConfig
 	SQL_result res;
 	struct GSM_SMSDdbobj *db = Config->db;
 	int i;
-	gboolean found = FALSE;
 	time_t timestamp;
 	const char *coding;
 	const char *text;
-	const char *sender_id;
 	size_t text_len;
 	const char *text_decoded;
 	const char *destination;
 	const char *udh;
 	const char *q;
 	size_t udh_len;
-	unsigned int limit = 1;
 	SQL_Var vars[3];
 
-	/* Min. limit is 8 SMS, limit grows with higher loopsleep setting  Max. limit is 30 messages.*/
-	limit = Config->loopsleep>1 ? Config->loopsleep * 4 : 8;
-	limit = limit>30 ? 30 : limit;
-
 	vars[0].type = SQL_TYPE_INT;
-	vars[0].v.i = limit;
+	vars[0].v.i = 1;
 	vars[1].type = SQL_TYPE_NONE;
 
-	if (SMSDSQL_NamedQuery(Config, SMSDSQL_queries[SQL_QUERY_FIND_OUTBOX_SMS_ID], NULL, vars, &res) != SQL_OK) {
-		SMSD_Log(DEBUG_INFO, Config, "Error reading from database (%s)", __FUNCTION__);
-		return ERR_UNKNOWN;
-	}
+	while (TRUE) {
+		if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_FIND_OUTBOX_SMS_ID], NULL, vars, &res) != SQL_OK) {
+			SMSD_Log(DEBUG_INFO, Config, "Error reading from database (%s)", __FUNCTION__);
+			return ERR_UNKNOWN;
+		}
+
+		if (db->NextRow(Config, &res) != 1) {
+			db->FreeResult(Config, &res);
+			return ERR_EMPTY;
+		}
 
-	while (db->NextRow(Config, &res)) {
 		sprintf(ID, "%ld", (long)db->GetNumber(Config, &res, 0));
 		timestamp = db->GetDate(Config, &res, 1);
+
+		db->FreeResult(Config, &res);
+
 		if (timestamp == -1) {
 			SMSD_Log(DEBUG_INFO, Config, "Invalid date for InsertIntoDB.");
 			return ERR_UNKNOWN;
 		}
+
 		SMSDSQL_Time2String(Config, timestamp, Config->DT, sizeof(Config->DT));
-		sender_id = db->GetString(Config, &res, 3);
-		if (sender_id == NULL || strlen(sender_id) == 0 || !strcmp(sender_id, Config->PhoneID)) {
-			if (SMSDSQL_RefreshSendStatus(Config, ID) == ERR_NONE) {
-				found = TRUE;
-				break;
-			}
+		if (SMSDSQL_RefreshSendStatus(Config, ID) == ERR_NONE) {
+			break;
 		}
 	}
 
-	db->FreeResult(Config, &res);
-
-	if (!found) {
-		return ERR_EMPTY;
-	}
-
 	sms->Number = 0;
 	for (i = 0; i < GSM_MAX_MULTI_SMS; i++) {
 		GSM_SetDefaultSMSData(&sms->SMS[i]);
@@ -796,9 +770,9 @@ static GSM_Error SMSDSQL_FindOutboxSMS(GSM_MultiSMSMessage * sms, GSM_SMSDConfig
 		vars[1].v.i = i;
 		vars[2].type = SQL_TYPE_NONE;
 		if (i == 1) {
-			q = SMSDSQL_queries[SQL_QUERY_FIND_OUTBOX_BODY];
+			q = Config->SMSDSQL_queries[SQL_QUERY_FIND_OUTBOX_BODY];
 		} else {
-			q = SMSDSQL_queries[SQL_QUERY_FIND_OUTBOX_MULTIPART];
+			q = Config->SMSDSQL_queries[SQL_QUERY_FIND_OUTBOX_MULTIPART];
 		}
 		if (SMSDSQL_NamedQuery(Config, q, NULL, vars, &res) != SQL_OK) {
 			SMSD_Log(DEBUG_ERROR, Config, "Error reading from database (%s)", __FUNCTION__);
@@ -914,13 +888,13 @@ static GSM_Error SMSDSQL_MoveSMS(GSM_MultiSMSMessage * sms UNUSED, GSM_SMSDConfi
 	vars[0].v.s = ID;
 	vars[1].type = SQL_TYPE_NONE;
 
-	if (SMSDSQL_NamedQuery(Config, SMSDSQL_queries[SQL_QUERY_DELETE_OUTBOX], NULL, vars, &res) != SQL_OK) {
+	if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_DELETE_OUTBOX], NULL, vars, &res) != SQL_OK) {
 		SMSD_Log(DEBUG_INFO, Config, "Error deleting from database (%s)", __FUNCTION__);
 		return ERR_UNKNOWN;
 	}
 	db->FreeResult(Config, &res);
 
-	if (SMSDSQL_NamedQuery(Config, SMSDSQL_queries[SQL_QUERY_DELETE_OUTBOX_MULTIPART], NULL, vars, &res) != SQL_OK) {
+	if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_DELETE_OUTBOX_MULTIPART], NULL, vars, &res) != SQL_OK) {
 		SMSD_Log(DEBUG_INFO, Config, "Error deleting from database (%s)", __FUNCTION__);
 		return ERR_UNKNOWN;
 	}
@@ -946,9 +920,9 @@ static GSM_Error SMSDSQL_CreateOutboxSMS(GSM_MultiSMSMessage * sms, GSM_SMSDConf
 	for (i = 0; i < sms->Number; i++) {
 		report = (sms->SMS[i].PDU == SMS_Status_Report) ? "yes": "default"; /* %2 */
 		if (i == 0) {
-			q = SMSDSQL_queries[SQL_QUERY_CREATE_OUTBOX];
+			q = Config->SMSDSQL_queries[SQL_QUERY_CREATE_OUTBOX];
 		} else {
-			q = SMSDSQL_queries[SQL_QUERY_CREATE_OUTBOX_MULTIPART];
+			q = Config->SMSDSQL_queries[SQL_QUERY_CREATE_OUTBOX_MULTIPART];
 		}
 
 		vars[0].type = SQL_TYPE_STRING;
@@ -1028,13 +1002,13 @@ static GSM_Error SMSDSQL_AddSentSMSInfo(GSM_MultiSMSMessage * sms, GSM_SMSDConfi
 	vars[4].v.s = Config->DT;
 	vars[5].type = SQL_TYPE_NONE;
 
-	if (SMSDSQL_NamedQuery(Config, SMSDSQL_queries[SQL_QUERY_ADD_SENT_INFO], &sms->SMS[Part - 1], vars, &res) != SQL_OK) {
+	if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_ADD_SENT_INFO], &sms->SMS[Part - 1], vars, &res) != SQL_OK) {
 		SMSD_Log(DEBUG_INFO, Config, "Error writing to database (%s)", __FUNCTION__);
 		return ERR_UNKNOWN;
 	}
 	db->FreeResult(Config, &res);
 
-	if (SMSDSQL_NamedQuery(Config, SMSDSQL_queries[SQL_QUERY_UPDATE_SENT], &sms->SMS[Part - 1], NULL, &res) != SQL_OK) {
+	if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_UPDATE_SENT], &sms->SMS[Part - 1], NULL, &res) != SQL_OK) {
 		SMSD_Log(DEBUG_INFO, Config, "Error updating number of sent messages (%s)", __FUNCTION__);
 		return ERR_UNKNOWN;
 	}
@@ -1054,7 +1028,7 @@ static GSM_Error SMSDSQL_RefreshPhoneStatus(GSM_SMSDConfig * Config)
 	vars[0].v.i = Config->Status->Charge.BatteryPercent;
 	vars[1].v.i = Config->Status->Network.SignalPercent;
 
-	if (SMSDSQL_NamedQuery(Config, SMSDSQL_queries[SQL_QUERY_REFRESH_PHONE_STATUS], NULL, vars, &res) != SQL_OK) {
+	if (SMSDSQL_NamedQuery(Config, Config->SMSDSQL_queries[SQL_QUERY_REFRESH_PHONE_STATUS], NULL, vars, &res) != SQL_OK) {
 		SMSD_Log(DEBUG_INFO, Config, "Error writing to database (%s)", __FUNCTION__);
 		return ERR_UNKNOWN;
 	}
@@ -1080,7 +1054,7 @@ GSM_Error SMSDSQL_option(GSM_SMSDConfig *Config, int optint, const char *option,
 	buffer = INI_GetValue(Config->smsdcfgfile, "sql", option, FALSE);
 	/* found? */
 	if (buffer != NULL){
-		SMSDSQL_queries[optint] = strdup(buffer); /* avoid to double free */
+		Config->SMSDSQL_queries[optint] = strdup(buffer); /* avoid to double free */
 		return ERR_NONE;
 	}
 
@@ -1112,7 +1086,7 @@ GSM_Error SMSDSQL_option(GSM_SMSDConfig *Config, int optint, const char *option,
 		ptr += len[j];
 	}
 	*ptr = '\0';
-	SMSDSQL_queries[optint] = buffer;
+	Config->SMSDSQL_queries[optint] = buffer;
 	return ERR_NONE;
 }
 
